==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/EditorRowCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { EditorRowCellInfoDescription } from "./EditorRowCellInfoDescription";
/**
 * @hidden
 */
var EditorRowCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(EditorRowCellInfoDescriptionMetadata, _super);
    function EditorRowCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EditorRowCellInfoDescriptionMetadata.b = function (a) {
        if (EditorRowCellInfoDescriptionMetadata.a == null) {
            EditorRowCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            EditorRowCellInfoDescriptionMetadata.c(EditorRowCellInfoDescriptionMetadata.a);
        }
        if (a.k(EditorRowCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.aa(EditorRowCellInfoDescriptionMetadata.a);
    };
    EditorRowCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
    };
    EditorRowCellInfoDescriptionMetadata.d = function (a) {
        EditorRowCellInfoDescriptionMetadata.b(a);
        a.ac("EditorRowCellInfo", function () { return new EditorRowCellInfoDescription(); });
        a.ab("EditorRowCellInfo", EditorRowCellInfoDescriptionMetadata.a);
    };
    EditorRowCellInfoDescriptionMetadata.$t = markType(EditorRowCellInfoDescriptionMetadata, 'EditorRowCellInfoDescriptionMetadata');
    EditorRowCellInfoDescriptionMetadata.a = null;
    return EditorRowCellInfoDescriptionMetadata;
}(Base));
export { EditorRowCellInfoDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/EditorRowCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { EditorRowCellInfoDescription } from "./EditorRowCellInfoDescription";
/**
 * @hidden
 */
var EditorRowCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(EditorRowCellInfoDescriptionMetadata, _super);
    function EditorRowCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EditorRowCellInfoDescriptionMetadata.b = function (a) {
        if (EditorRowCellInfoDescriptionMetadata.a == null) {
            EditorRowCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            EditorRowCellInfoDescriptionMetadata.c(EditorRowCellInfoDescriptionMetadata.a);
        }
        if (a.k(EditorRowCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.ac(EditorRowCellInfoDescriptionMetadata.a);
    };
    EditorRowCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
    };
    EditorRowCellInfoDescriptionMetadata.d = function (a) {
        EditorRowCellInfoDescriptionMetadata.b(a);
        a.ae("EditorRowCellInfo", function () { return new EditorRowCellInfoDescription(); });
        a.ad("EditorRowCellInfo", EditorRowCellInfoDescriptionMetadata.a);
    };
    EditorRowCellInfoDescriptionMetadata.$t = markType(EditorRowCellInfoDescriptionMetadata, 'EditorRowCellInfoDescriptionMetadata');
    EditorRowCellInfoDescriptionMetadata.a = null;
    return EditorRowCellInfoDescriptionMetadata;
}(Base));
export { EditorRowCellInfoDescriptionMetadata };
